@@ -17,7 +17,7 @@ use crate::messaging::{
 use crate::node::{node_ops::NodeDuty, Error, Result};
 use crate::routing::Prefix;
 use crate::types::PublicKey;
-use log::info;
+use tracing::info;
 
 /// The various data type stores,
 /// that are only managed at Elders.
